# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-06-12 06:43
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0061_auto_20181221_1443'),
    ]

    operations = [
        migrations.AddField(
            model_name='video',
            name='file_name',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u89c6\u9891\u6587\u4ef6\u540d'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'
from django.contrib.auth.models import User
from .models import CourseSectionMid, UserCourseSection, UserCourse
from .utils import get_user_live_data


# django前台显示本地时间
def filter_local_datetime(_datetime):
    return _datetime


# 获取一个助教，所教的所有学生
def get_teach_users(mentor):
    return User.objects.all()


# 获取用户所学课程的课件列表，排序
def get_user_course_section_list(user_course, section_type_list=None):
    m_list = CourseSectionMid.objects.filter(course=user_course.course).order_by('order_by')
    section_list = user_course.usercoursesection_set.filter(section__coursesectionmid__in=m_list) \
        .order_by('section__coursesectionmid__order_by')
    if section_type_list:
        section_list = section_list.filter(section__type__in=section_type_list)
    return section_list


# 获取直播的分钟数，和次数
def get_user_live_mins_count_days(user, start_dt=None, end_dt=None):
    return get_user_live_data(user, start_dt, end_dt)


def get_user_last_course_section(user, start_dt=None, end_dt=None):
    return UserCourseSection.get_user_last_course_section(user, start_dt, end_dt)



def get_current_user_course(user):
    uc_list = UserCourse.objects.filter(user=user).order_by('-created_at')
    if uc_list.exists():
        return uc_list.first()
    else:
        return None


# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-16 09:57
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0065_auto_20190813_1743'),
    ]

    operations = [
        migrations.AddField(
            model_name='usercoursesection',
            name='learned_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='\u5f00\u59cb\u5b66\u4e60\u65f6\u95f4'),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='minus_mins',
            field=models.IntegerField(default=0, verbose_name='\u6263\u51cf\u7684\u65f6\u95f4'),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='passed_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='\u8bfe\u4ef6\u901a\u8fc7\u65f6\u95f4'),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='send_message_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='\u7ed9\u52a9\u6559\u53d1\u6d88\u606f\u65f6\u95f4'),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='teacher_add_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='\u52a9\u6559\u64cd\u4f5c\u65f6\u95f4'),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='teacher_add_mins',
            field=models.IntegerField(blank=True, null=True, verbose_name='\u52a9\u6559\u589e\u52a0\u7684\u7ec3\u4e60\u65f6\u95f4'),
        ),
    ]



# -*- coding:utf-8 -*-
__author__ = 'bee'

from django import forms
from django.db.models import Q
from django.conf import settings

from .models import Course, Section, CourseSectionMid, Video, UserImage, UserCourse, UserAssignment, \
    UserAssignmentImage, SectionVideo, Preference, SectionAttach, UserSectionNote, UserLiveComment,UserCourseSection
from django.forms.models import inlineformset_factory
import os.path
from django.core.exceptions import ValidationError


# ===== course contract======
class CourseForm(forms.ModelForm):
    status = forms.ChoiceField(choices=((0, '显示'), (1, '不显示')), label='显示状态')

    class Meta:
        model = Course
        fields = ['name', "subtitle", "level", "status", "punch_period", "punch_duration", "image"]


# ===== section contract======
class SectionForm(forms.ModelForm):
    class Meta:
        model = Section
        fields = ['name', 'image', "info", "has_videowork",
                  'video_length_req',
                  'has_imagework', 'image_count_req', 'auto_pass', 'pass_cooldown',
                  'has_questionwork','need_certify']

    def __init__(self, *args, **kwargs):
        super(SectionForm, self).__init__(*args, **kwargs)
        if hasattr(settings, 'COURSE_VIDEO_PROVIDER_NAME') and settings.COURSE_VIDEO_PROVIDER_NAME == 'qiniu':
            self.fields["has_to_finish_course_video"] = forms.BooleanField(label=u'是否需要看完课件所有视频',
                                                                           help_text=u'看完视频要求目前只对七牛云视频有效',
                                                                           required=False)
            if kwargs["instance"]:
                self.initial['has_to_finish_course_video'] = kwargs["instance"].has_to_finish_course_video


class SectionAttachForm(forms.ModelForm):
    class Meta:
        model = SectionAttach
        fields = ['file', 'name']


section_attach_form = inlineformset_factory(Section, SectionAttach, form=SectionAttachForm, extra=1)


# 用户笔记
class UserSectionNoteForm(forms.ModelForm):
    class Meta:
        model = UserSectionNote
        fields = ['note', 'is_open']


class CourseSectionForm(forms.ModelForm):
    class Meta:
        model = CourseSectionMid
        fields = ['section', 'pre_name', 'order_by', 'points']

    def __init__(self, course=None, *args, **kwargs):
        super(CourseSectionForm, self).__init__(*args, **kwargs)
        if course:
            self.fields['section'].queryset = Section.objects.filter(~Q(coursesectionmid__course=course))


class CourseSectionOrderForm(forms.ModelForm):
    class Meta:
        model = CourseSectionMid
        fields = ['pre_name', 'order_by', 'points']


class CourseSectionMinForm(forms.ModelForm):
    class Meta:
        model = CourseSectionMid
        fields = ['section', 'order_by', 'mins']


# 课件问题
class CourseSectionQuestionSearchForm(forms.Form):
    question_has_correct_choices = ((-1, '全部'), (1, "有"), (0, "无"))
    question_has_correct = forms.ChoiceField(choices=question_has_correct_choices, label='正确答案', required=False)
    question_name = forms.CharField(label='问题', required=False)


class VideoForm(forms.ModelForm):
    class Meta:
        model = Video
        fields = ['title', 'info']


class UploadImageForm(forms.ModelForm):
    class Meta:
        model = UserImage
        fields = ['image']


class UserCourseForm(forms.ModelForm):
    class Meta:
        model = UserCourse
        fields = ('course',)

    def __init__(self, user, *args, **kwargs):
        super(UserCourseForm, self).__init__(*args, **kwargs)

        self.fields['course'].queryset = Course.objects.exclude(usercourse__user=user)


class UserAssignmentForm(forms.ModelForm):
    class Meta:
        model = UserAssignment
        fields = ['content', ]


class UserAssignmentImageForm(forms.ModelForm):
    image = forms.ImageField(label='图片作业', required=False)

    class Meta:
        model = UserAssignmentImage
        fields = ['image']


class SectionVideoForm(forms.ModelForm):
    class Meta:
        model = SectionVideo
        fields = ['video', 'order']

    def __init__(self, section=None, *args, **kwargs):
        super(SectionVideoForm, self).__init__(*args, **kwargs)

        if section:
            self.fields['video'].queryset = Video.objects.exclude(sectionvideo__section=section)


class SectionVideoOrderForm(forms.ModelForm):
    class Meta:
        model = SectionVideo
        fields = ['order']


class PreferenceForm(forms.ModelForm):
    how_to_pass = forms.ChoiceField(choices=((0, '自动'), (1, '手动')), label='课程通过方式')

    class Meta:
        model = Preference
        fields = ['how_to_pass', ]


class LivePlayLogsForm(forms.Form):
    video_id = forms.CharField(required=True, max_length=100, label='视频video_id')
    date = forms.CharField(required=True, max_length=100, label='日期', help_text='格式：2000-01-01')


class UserLiveSearchForm(forms.Form):
    status = forms.ChoiceField(choices=((0, '全部'), (1, '正常'), (-1, '删除'),), required=False, label='状态', )
    name = forms.CharField(required=False, max_length=100, label='学生', )

    def __init__(self, provider_list, *args, **kwargs):
        super(UserLiveSearchForm, self).__init__(*args, **kwargs)
        if provider_list:
            self.fields['provider'] = forms.ChoiceField(label='服务商', choices=provider_list, required=False)


class UserLiveCommentForm(forms.ModelForm):
    class Meta:
        model = UserLiveComment
        fields = ['comment', ]


class ReportUserLiveSearchForm(forms.Form):
    start_time = forms.CharField(label='开始时间', required=False)
    end_time = forms.CharField(label='结束时间', required=False)


class ReportUserCourseSectionSearchForm(forms.Form):
    status = forms.ChoiceField(label='学生状态', choices=((0, '全部'), (1, "正常")), required=False)
    course = forms.ModelChoiceField(queryset=Course.objects.all(),label='课程', required=False)
    section = forms.ModelChoiceField(queryset=Section.objects.all(),label='课件', required=False)
    is_passed = forms.BooleanField(label='是否通过',required=False)



# -*- coding:utf-8 -*-
import time, datetime
from django.core.management.base import BaseCommand
from bee_django_course.models import UserLive
from django.utils import timezone

from bee_django_course import cc


class Command(BaseCommand):

    def add_arguments(self, parser):
        parser.add_argument('days', type=int, nargs='?', default=20)

    def handle(self, *args, **options):
        # 默认删除20天前的录播
        days = options["days"]
        for e in UserLive.objects.filter(created_at__lt=timezone.now() - datetime.timedelta(days=days), status=1):
            if e.provider_name == u'cc':
                if e.record_video_id and e.record_status == '10':
                    cc.delete_video(e.record_video_id)
                    time.sleep(1)
            elif e.provider_name == u'gensee':
                pass
            elif e.provider_name == u'tencent':
                pass
            e.status = 2
            e.save()

        return



# -*- coding:utf-8 -*-
import time, datetime
from django.core.management.base import BaseCommand
from bee_django_course.models import UserCourseSection
from django.utils import timezone

class Command(BaseCommand):

    # 检查自动通过，并且设置间隔时间的课件，达标后自动通过
    def handle(self, *args, **options):
        ucs_list = UserCourseSection.objects.filter(section__auto_pass=True, status=1, section__pass_cooldown__gt=0)
        i = 0
        for ucs in ucs_list:
            if ucs.auto_pass_check():
                ucs.get_pass()
                i += 1
        print("["+timezone.localtime().strftime("%Y-%m-%d %H:%M:%S")+"] auto_pass_count: " + i.__str__() + "/" + ucs_list.count().__str__())
        return



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-15 03:18
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_course', '0035_auto_20180611_1624'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserSectionNote',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('note', models.TextField(verbose_name='\u7b14\u8bb0')),
                ('is_open', models.BooleanField(default=True, verbose_name='\u662f\u5426\u516c\u5f00')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
        migrations.AlterField(
            model_name='section',
            name='has_videowork',
            field=models.BooleanField(default=True, verbose_name='\u662f\u5426\u9700\u8981\u89c6\u9891\u5f55\u5236'),
        ),
        migrations.AddField(
            model_name='usersectionnote',
            name='section',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.Section'),
        ),
        migrations.AddField(
            model_name='usersectionnote',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-30 08:15
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0081_userlive_is_certify'),
    ]

    operations = [
        migrations.AddField(
            model_name='userlive',
            name='ucs',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserCourseSection'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
from __future__ import unicode_literals
import datetime, pytz
from django.core.urlresolvers import reverse
from django.db import models, transaction
from django.contrib.auth.models import User
from django.utils import timezone
from django.conf import settings
from django.db.models.functions import TruncMonth, TruncDay

import os, random
from django.dispatch import receiver
from django.db.models.signals import post_save
from .signals import ucs_passed
from PIL import Image, ExifTags
from django.db.models import Q, Sum, Count
from django.db import connection
from .signals import user_course_changed, user_certify_update_status
# Create your models here.
from .dt import get_datetime_with_scope_offset, LOCAL_TIMEZONE
from django.conf import settings
from bee_django_object_field.custom_fields import DictField

if hasattr(settings, 'ASSIGNMENT_IMG_SIZE'):
    ASSIGNMENT_IMG_SIZE = settings.ASSIGNMENT_IMG_SIZE
else:
    ASSIGNMENT_IMG_SIZE = (1024, 768)

if hasattr(settings, 'COURSE_IMG_SIZE'):
    COURSE_IMG_SIZE = settings.COURSE_IMG_SIZE
else:
    COURSE_IMG_SIZE = (800, 600)


# 压缩上传作业图片
def resize_assignment_image(img_field):
    img = Image.open(img_field)

    try:
        for orientation in ExifTags.TAGS.keys():
            if ExifTags.TAGS[orientation] == 'Orientation':
                exif = dict(img._getexif().items())

                if exif[orientation] == 3:
                    img = img.rotate(180, expand=True)
                elif exif[orientation] == 6:
                    img = img.rotate(270, expand=True)
                elif exif[orientation] == 8:
                    img = img.rotate(90, expand=True)

                break
    except:
        pass

    img.thumbnail(ASSIGNMENT_IMG_SIZE, Image.ANTIALIAS)
    img.save(img_field.path)

    img.close()


# 压缩课程课件配图
def resize_course_image(img_field):
    img = Image.open(img_field)

    try:
        for orientation in ExifTags.TAGS.keys():
            if ExifTags.TAGS[orientation] == 'Orientation':
                exif = dict(img._getexif().items())

                if exif[orientation] == 3:
                    img = img.rotate(180, expand=True)
                elif exif[orientation] == 6:
                    img = img.rotate(270, expand=True)
                elif exif[orientation] == 8:
                    img = img.rotate(90, expand=True)

                break
    except:
        pass

    img.thumbnail(COURSE_IMG_SIZE, Image.ANTIALIAS)
    img.save(img_field.path)

    img.close()


# 课程
class Course(models.Model):
    name = models.CharField(max_length=180, verbose_name='课程名字')  # 名字
    subtitle = models.CharField(max_length=180, null=True, verbose_name='课程副标题', blank=True)  # 副标题
    level = models.IntegerField(default=0, verbose_name='课程的level', blank=True)  # 课程的level
    is_del = models.IntegerField(default=0)
    created_at = models.DateTimeField(default=timezone.now)
    teacher = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True, verbose_name='授课老师')
    image = models.ImageField(null=True, blank=True, verbose_name='配图', upload_to='course/face')
    status = models.IntegerField(verbose_name='状态', default=0)  # 0 不显示，1 显示在列表
    template = models.CharField(max_length=180, null=True, blank=True, verbose_name='模版',
                                help_text='在项目中custom_user下新建模版文件custom_user_course_section_list_[template].html')
    punch_period = models.IntegerField(choices=((1, '天'),), verbose_name='周期', help_text='用于课程打卡，如不需要可不填写', null=True,
                                       blank=True)  # month/week/day
    punch_duration = models.IntegerField(verbose_name='时长', null=True, blank=True, help_text='用于课程打卡，如不需要可不填写')  # 时长

    class Meta:
        db_table = 'bee_django_course_course'
        app_label = 'bee_django_course'
        ordering = ["-id"]
        verbose_name = 'course课程'
        permissions = (
            ('can_manage_course', '可以进入课程管理页'),
            ('view_all_courses', '可以查看所有课程'),
            ('can_choose_course', 'can choose course'),
        )

    def __unicode__(self):
        return self.name

    def get_absolute_url(self):
        return reverse('bee_django_course:course_detail', kwargs={'pk': self.pk})

    def is_my_course(self, user):
        user_course = UserCourse.objects.filter(user=user, course=self)
        if user_course.exists():
            return user_course.first()
        else:
            return None

    def get_punch_period_str(self):
        if self.punch_period == 1:
            return '天'
        if self.punch_period == 7:
            return '天'
        return ''


class Section(models.Model):
    name = models.CharField(max_length=180, verbose_name='课件名字')  # 名字
    info = models.TextField(null=True, blank=True, verbose_name='正文')
    videos = models.ManyToManyField("bee_django_course.Video")
    has_textwork = models.BooleanField(verbose_name='是否需要文字作业', default=False)
    textwork_info = models.TextField(verbose_name='作业说明', null=True, blank=True)
    has_videowork = models.BooleanField(verbose_name='是否需要视频录制', default=False)
    has_imagework = models.BooleanField(verbose_name='是否需要上传图片', default=False)
    has_questionwork = models.BooleanField(verbose_name='是否需要回答问题', default=False)
    question_passed_at = models.DateTimeField(verbose_name='问答通过时间', null=True, blank=True)
    video_length_req = models.IntegerField(verbose_name='要求录制时长(分钟)', default=0)
    image_count_req = models.IntegerField(verbose_name='要求提交图片数量', default=0)

    has_to_finish_course_video = models.BooleanField(verbose_name='是否需要看完课件所有视频', default=False)

    created_at = models.DateTimeField(default=timezone.now)
    auto_pass = models.BooleanField(default=False, verbose_name='是否自动通过')  # 课件是否自动通过
    pass_cooldown = models.IntegerField(default=0, verbose_name='间隔天数', help_text='通过时距离上一课件的间隔天数')
    type = models.IntegerField(default=0)  # 0 普通课件，1 预备课件

    image = models.ImageField(null=True, blank=True, verbose_name='配图', upload_to='section/face')

    need_certify = models.BooleanField(verbose_name='是否需要认证', default=False)

    #                                    help_text='认证课件将在其他条件达标后 显示认证按钮')

    class Meta:
        db_table = 'bee_django_course_section'
        app_label = 'bee_django_course'
        ordering = ["-id"]
        verbose_name = 'course课件'
        permissions = (
            ('view_all_sections', '可以查看所有课件'),
        )

    def __unicode__(self):
        return self.name

    def get_absolute_url(self):
        return reverse('bee_django_course:section_detail', kwargs={'pk': self.pk})

    def get_auto_pass_text(self):
        if self.auto_pass:
            return '是'
        else:
            return '否'

    def get_questions(self):
        return self.sectionquestion_set.all()

    # 添加问题
    def add_question(self, question_type):
        question = SectionQuestion()
        question.section = self
        question.question_type = question_type
        question.question = '新建问题'
        question.save()
        return question


# 课件的用户笔记
class UserSectionNote(models.Model):
    section = models.ForeignKey(Section)
    user = models.ForeignKey(settings.AUTH_USER_MODEL)
    note = models.TextField(verbose_name='学习笔记')
    is_open = models.BooleanField(default=True, verbose_name='公开笔记')
    created_at = models.DateTimeField(default=timezone.now)
    updated_at = models.DateTimeField(default=timezone.now)
    is_stick = models.BooleanField(default=False, verbose_name='是否置顶')
    is_digest = models.BooleanField(default=False, verbose_name='是否精华')


# 课件的附件
class SectionAttach(models.Model):
    name = models.CharField(max_length=180, verbose_name='附件名称', null=True, blank=True)
    section = models.ForeignKey(Section)
    file = models.FileField(verbose_name='附件', upload_to='sections/%Y/%m/%d/')
    upload_at = models.DateTimeField(auto_now_add=True)

    class Meta:
        db_table = 'bee_django_course_section_attach'

    def file_name(self):
        if self.name:
            return self.name
        else:
            return os.path.basename(self.file.name)


# 课程课件中间件
class CourseSectionMid(models.Model):
    course = models.ForeignKey("bee_django_course.Course", verbose_name='课程')  # 课程
    section = models.ForeignKey("bee_django_course.Section", verbose_name="课件")  # 课程包
    points = models.IntegerField(default=0, verbose_name='通过后获得的M币')
    order_by = models.IntegerField(default=0, verbose_name="顺序")  # 顺序
    mins = models.IntegerField(null=True, blank=True, verbose_name='达标分钟数')  # 达标分钟数 #可能弃用
    pre_name = models.CharField(max_length=180, verbose_name='前缀标题', null=True, blank=True)

    class Meta:
        db_table = 'bee_django_course_section_mid'
        app_label = 'bee_django_course'
        ordering = ['order_by']

    def __unicode__(self):
        return ("CourseSectionMid->course:" + self.course.name)


class Video(models.Model):
    video_id = models.CharField(max_length=180, null=True)  # 视频 id，16位 hex 字符串
    status = models.CharField(max_length=180, null=True)  # 视频状态。”OK”表示视频处理成功，”FAIL”表示视频处理失败。
    duration = models.CharField(max_length=180, null=True)  # 片长（单位:秒）
    image = models.CharField(max_length=180, null=True)  # 视频截图地址
    # ===========
    title = models.CharField(max_length=180, null=True, verbose_name='标题')  # 视频标题
    file_name = models.CharField(max_length=180, null=True, blank=True, verbose_name='视频文件名')  # 七牛
    info = models.TextField(verbose_name='说明', null=True, blank=True)
    created_at = models.DateTimeField(auto_now_add=True)

    # created_by = models.ForeignKey("users.User", related_name='cc_video_user', null=True)  # 由谁上传
    # video_status = models.IntegerField(default=1, null=True)  # 状态 1-正常，2-正常（删除视频）

    class Meta:
        db_table = 'bee_django_course_video'
        app_label = 'bee_django_course'
        ordering = ['-created_at']
        verbose_name = 'course视频'
        permissions = (
            ('view_all_videos', '可以查看所有视频'),
        )

    def __unicode__(self):
        return ("视频:" + self.title)

    def get_absolute_url(self):
        # return reverse('bee_django_course:video_detail', kwargs={'pk': self.pk})
        return reverse('bee_django_course:video_list')


class SectionVideo(models.Model):
    section = models.ForeignKey(Section, verbose_name='关联的课件')
    video = models.ForeignKey(Video, verbose_name='关联的视频')
    created_at = models.DateTimeField(auto_now_add=True)
    order = models.IntegerField(default=0, verbose_name='在课件里的排序')

    class Meta:
        db_table = 'bee_django_course_section_video'
        ordering = ['order']


COURSE_SECTION_QUESTION_TYPE_CHOICES = ((1, "单选"), (2, "多选"))


class SectionQuestion(models.Model):
    section = models.ForeignKey(Section, verbose_name='关联的课件')
    question = models.CharField(max_length=180, verbose_name='问题')
    question_type = models.IntegerField(default=1, verbose_name='问题类型', choices=COURSE_SECTION_QUESTION_TYPE_CHOICES)
    order_by = models.IntegerField(default=0, verbose_name='顺序')
    options = models.ManyToManyField("bee_django_course.SectionQuestionOption")
    tip_wrong = models.TextField(null=True, verbose_name="错误时提示词")
    tip_correct = models.TextField(null=True, verbose_name="正确时提示词")

    class Meta:
        db_table = 'bee_django_course_section_question'
        ordering = ['order_by']
        permissions = (
            ('view_sectionquestion', '可以查看问题列表'),
        )

    # 添加选项
    def add_options(self, count=1):
        # 单选 或多选
        if int(self.question_type) == 1 or int(self.question_type) == 2:
            new_options = []
            for i in range(1, count + 1):
                option = SectionQuestionOption()
                option.question = self
                option.option = '选项' + i.__str__()
                option.order_by = i
                option.save()
                self.options.add(option)
                new_options.append(option)
            return new_options

    # 获取答题的正确答案
    def get_correct_options(self):
        return SectionQuestionOption.objects.filter(question=self, is_correct=True)

    # 获取【无】正确答案的问题
    @classmethod
    def get_has_correct_questions(cls, has_correct=False):
        if has_correct:
            return cls.objects.filter(options__is_correct=True)
        else:
            return cls.objects.exclude(options__is_correct=True)


class SectionQuestionOption(models.Model):
    question = models.ForeignKey(SectionQuestion, verbose_name='问题')
    option = models.CharField(max_length=180, verbose_name='选项')
    order_by = models.IntegerField(default=0, verbose_name='顺序')
    is_correct = models.BooleanField(default=False, verbose_name='是否正确答案')

    class Meta:
        app_label = "bee_django_course"
        db_table = 'bee_django_course_section_question_option'
        ordering = ['order_by']


# 每添加一个问题，自动创建选项
@receiver(post_save, sender=SectionQuestion)
def create_user(sender, **kwargs):
    section_question = kwargs['instance']
    if kwargs['created']:
        section_question.add_options(3)


class UserQuestionAnswerRecord(models.Model):
    user = models.ForeignKey(settings.AUTH_USER_MODEL)  # 学生
    question = models.ForeignKey(SectionQuestion)  # 问题
    answer = models.ForeignKey(SectionQuestionOption)  # 答案
    created_at = models.DateTimeField(auto_now_add=True)

    class Meta:
        db_table = 'bee_django_course_user_question_answer_record'
        app_label = 'bee_django_course'
        ordering = ['-created_at']

    def __unicode__(self):
        return ("UserQuestionAnswerRecord->user:" + self.user.username + ",question:" + self.question.question)

    @classmethod
    def get_user_question_answer_options(cls, question, user):
        return cls.objects.filter(question=question, user=user)
        # answer_option_list = []
        # for record in records:
        #     option_id_list.append(record.answer)
        # return SectionQuestionOption.objects.filter(id__in=option_id_list)


class UserLive(models.Model):
    provider_name = models.CharField(max_length=180, default=u'cc')  # 平台商
    cc_user_id = models.CharField(max_length=180, null=True)  # CC账号
    room_id = models.CharField(max_length=180, null=True)  # 直播间ID
    live_id = models.CharField(max_length=180, null=True)  # 直播ID
    stop_status = models.CharField(max_length=180, null=True)  # 直播结束状态，10：正常结束，20：非正常结束
    record_status = models.CharField(max_length=180, null=True)  # 直播录制状态，10：录制成功，20：录制失败，30：直播过长
    record_video_id = models.CharField(max_length=180, null=True)  # 录制视频ID（如果录制成功，则返回该参数）
    replay_url = models.CharField(max_length=180, null=True)  # 直播回放地址（如果录制成功，则返回该参数）
    start_time = models.DateTimeField(null=True)  # 直播开始时间
    end_time = models.DateTimeField(null=True)  # 直播结束时间
    user = models.ForeignKey(settings.AUTH_USER_MODEL)  # 学生
    duration = models.IntegerField(null=True)  # 秒
    record_video_duration = models.IntegerField(null=True)  # 秒 返回的视频时间
    status = models.IntegerField(default=1, null=True)  # 状态 1-正常，2-正常（删除视频），-1：删除 -2 删除（删除视频）
    created_at = models.DateTimeField(auto_now_add=True)
    call_count = models.IntegerField(default=1)  # 回调了几次
    coin_multiple = models.IntegerField(default=0)  # 加了几倍M币
    is_star = models.BooleanField(default=False)  # 是否标星
    is_certify = models.BooleanField(default=False)  # 是否是认证视频
    # ucs = models.ForeignKey('bee_django_course.UserCourseSection',null=True,blank=True) # 目前仅认证用
    is_mentor_view = models.BooleanField(default=False)  # 助教是否观看
    view_mentor_id = models.IntegerField(null=True)  # 观看的助教id，检查用，可删除

    class Meta:
        db_table = 'bee_django_course_user_live'
        app_label = 'bee_django_course'
        ordering = ['-created_at']
        verbose_name = 'course学生录播'
        permissions = (
            ('view_all_userlives', '可以查看所有学生的录播'),
            ('view_teach_userlives', '可以查看所教的学生的录播'),
            ('view_child_userlives', '可以查看亲子学生的录播'),
            ('view_expired_userlives', '可以查看超过指定时间的录播'),
        )

    def __unicode__(self):
        return ("UserLive->id:" + self.pk.__str__())

    # 获取开始时间的筛选条件
    @classmethod
    def get_start_time_filter(cls, scope=None, offset=None):
        if scope in ["day", 'week', "month"]:
            start_dt, end_dt = get_datetime_with_scope_offset(scope, offset)
            return Q(start_time__range=[start_dt, end_dt])
        else:
            return None

    def get_duration_str(self, format_str=None):
        if not self.duration:
            return 0
        # print(type(seconds))
        # seconds=int(seconds)
        hour = self.duration / 3600
        min = (self.duration - hour * 3600) / 60
        second = (self.duration - hour * 3600 - min * 60)

        if not format_str:
            return '%02d:%02d:%02d' % (hour, min, second)

        elif format_str == 'min':
            return '%s' % (hour * 60 + min)

        return

    @classmethod
    # 获取某[些]学生的：直播分钟数，直播次数，助教观看次数
    def get_user_live_report(cls, user_list, start_dt, end_dt):
        user_live_list = cls.objects.filter(user__in=user_list, status__in=[1, 2])
        if start_dt:
            user_live_list = user_live_list.filter(start_time__gte=start_dt)
        if end_dt:
            user_live_list = user_live_list.filter(start_time__lt=end_dt)
        if not user_live_list.exists():
            return 0, 0, 0, 0, 0
        # 分钟数
        user_live_mins_res = user_live_list.aggregate(Sum("duration"))
        if user_live_mins_res["duration__sum"]:
            mins = user_live_mins_res["duration__sum"] / 60
        else:
            mins = 0
        # 次数
        user_live_count_res = user_live_list.aggregate(Count("id"))
        if user_live_count_res["id__count"]:
            count = user_live_count_res["id__count"]
        else:
            count = 0
        # 练习天数
        user_live_days_res = user_live_list.annotate(day=TruncDay('start_time', tzinfo=LOCAL_TIMEZONE)).values(
            'day').annotate(count=Count('id'), total=Sum('duration')).values('day', 'count', 'total').order_by('day')
        days = user_live_days_res.count()
        # 助教观看次数
        mentor_view_list = user_live_list.filter(is_mentor_view=True)
        mentor_view_count = mentor_view_list.count()
        # 助教观看天数
        mentor_view_days_res = mentor_view_list.annotate(day=TruncDay('start_time', tzinfo=LOCAL_TIMEZONE)).values(
            'day').annotate(count=Count('id'), total=Sum('duration')).values('day', 'count', 'total').order_by('day')
        mentor_view_days = mentor_view_days_res.count
        return mins, count, days, mentor_view_count, mentor_view_days

    # 获取某[些]学生的直播分钟数，直播次数，助教观看次数 准备弃用，改用get_user_live_report
    @classmethod
    def get_user_live_detail(cls, user_list, scope=None, offset=None):
        user_live_list = cls.objects.filter(user__in=user_list, status__in=[1, 2])
        q = cls.get_start_time_filter(scope, offset)
        if q:
            user_live_list = user_live_list.filter(q)
        # if start_dt:
        #     user_live_list=user_live_list.filter(start_time__gte=start_dt)
        # if end_dt:
        #     user_live_list=user_live_list.filter(start_time__lt=end_dt)
        if not user_live_list.exists():
            return 0, 0, 0
        # 分钟数
        user_live_mins_res = user_live_list.aggregate(Sum("duration"))
        if user_live_mins_res["duration__sum"]:
            mins = user_live_mins_res["duration__sum"] / 60
        else:
            mins = 0
        # 次数
        user_live_count_res = user_live_list.aggregate(Count("id"))
        if user_live_count_res["id__count"]:
            count = user_live_count_res["id__count"]
        else:
            count = 0

        mentor_view_list = user_live_list.filter(is_mentor_view=True)
        mentor_view_count = mentor_view_list.count()
        return mins, count, mentor_view_count

    # 检查学员的助教是否点评了此次录播
    def get_mentor_comments_status(self):
        user_profile = self.user.userprofile
        if user_profile:
            user_class = self.user.userprofile.user_class
            if user_class:
                mentor = user_class.assistant
                if mentor:
                    mentor_comments = self.userlivecomment_set.filter(user=mentor)
                    if mentor_comments.exists():
                        return True
                    else:
                        return False
                else:
                    return False
            else:
                return False
        else:
            return False

    # 助教评论了学生的几个录播数
    @classmethod
    def get_mentor_comment_count(cls, user, start_dt=None, end_dt=None):
        user_live_list = cls.objects.filter(user=user, status__in=[1, 2])
        if start_dt:
            user_live_list = user_live_list.filter(start_time__gte=start_dt)
        if end_dt:
            user_live_list = user_live_list.filter(start_time__lt=end_dt)
        mentor = User.get_assistant()
        if not mentor:
            return 0
        if not user_live_list.exists():
            return 0

        user_live_list = user_live_list.filter(userlivecomment__user=mentor)
        if start_dt:
            user_live_list = user_live_list.filter(userlivecomment__submit_date__gte=start_dt)
        if end_dt:
            user_live_list = user_live_list.filter(userlivecomment__submit_date__lt=end_dt)
        return user_live_list.count()


class UserLiveComment(models.Model):
    user = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name='作者')
    user_live = models.ForeignKey(UserLive)
    comment = models.TextField(verbose_name='评论')
    submit_date = models.DateTimeField(verbose_name='提交日期', default=timezone.now, db_index=True)


# 课件info中富文本的图片
class UserImage(models.Model):
    user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True)
    image = models.ImageField(verbose_name='图片', upload_to='course/%Y/%m/%d')
    upload_at = models.DateTimeField(verbose_name='上传时间', auto_now_add=True)

    class Meta:
        db_table = 'bee_django_course_user_image'


class UserCourse(models.Model):
    user = models.ForeignKey(settings.AUTH_USER_MODEL)
    course = models.ForeignKey(Course, verbose_name='课程')
    created_at = models.DateTimeField(auto_now_add=True)
    status = models.IntegerField(default=0, verbose_name='状态')  # 0 学习中，1 已完成
    passed_at = models.DateTimeField(null=True, blank=True)

    class Meta:
        db_table = 'bee_django_course_user_course'
        permissions = [
            ('assign_user_course', '能给学生分配课程'),
        ]

    def get_pass(self):
        self.status = 1
        self.passed_at = timezone.now()
        self.save()
        user_course_changed.send(sender=self.__class__, user_course=self, status=1)

    # 打卡统计
    def get_user_course_punch_count(self):
        course = self.course
        count = 0
        created_at = self.created_at
        # 按天打卡
        if course.punch_period == 1:
            sql = '''
            select count(*)from(select start_time::date as m from "public".bee_django_course_user_live where user_id = %s and start_time >= %s union select question_passed_at::date as m from "public".bee_django_course_user_course_section where user_course_id = %s and question_passed_at >= %s union select upload_at::date as m from "public".bee_django_course_user_assignment_image where user_course_section_id in (select id from "public".bee_django_course_user_course_section where user_course_id = %s) and upload_at >= %s union select created_at::date as m from "public".bee_django_course_user_assignment where user_course_section_id in (select id from "public".bee_django_course_user_course_section where user_course_id = %s) and created_at >= %s) as a where a.m >= %s and a.m <= %s;
            '''
            with connection.cursor() as cursor:
                cursor.execute(sql, [self.user.id, created_at, self.id, created_at, self.id, created_at, self.id,
                                     created_at, created_at.strftime('%Y-%m-%d'),
                                     (self.passed_at or timezone.now()).strftime('%Y-%m-%d')])
                row = cursor.fetchone()
                count = row[0]
            if count > course.punch_duration:
                count = course.punch_duration
        # 按周打卡
        if course.punch_period == 7:
            pass
        return count


class UserCourseSection(models.Model):
    user_course = models.ForeignKey(UserCourse)
    section = models.ForeignKey(Section)
    created_at = models.DateTimeField(auto_now_add=True)
    learned_at = models.DateTimeField(verbose_name='开始学习时间', blank=True, null=True)
    passed_at = models.DateTimeField(verbose_name='课件通过时间', blank=True, null=True)
    status = models.IntegerField(default=0)  # 0 未开始， 1 学习中，2 通过，3 退回重修（删除）, 4 提交（删除）
    score = models.IntegerField(blank=True, null=True, verbose_name='得分')
    work_time = models.IntegerField(verbose_name='总共练习时间',
                                    null=True, blank=True, default=0)  # 学生总共练习时间
    minus_live_mins = models.IntegerField(verbose_name='扣减的时间', default=0)
    teacher_add_mins = models.IntegerField(verbose_name='助教增加的练习时间', null=True, blank=True)
    teacher_add_at = models.DateTimeField(verbose_name='助教操作时间', null=True, blank=True)
    send_message_at = models.DateTimeField(verbose_name='给助教发消息时间', null=True, blank=True)
    comment = models.TextField(null=True, blank=True, verbose_name='评语')  # 弃用
    question_passed = models.BooleanField(default=False)
    question_passed_at = models.DateTimeField(null=True, blank=True)

    # 准备弃用
    updated_at = models.DateTimeField(default=timezone.now)

    class Meta:
        db_table = 'bee_django_course_user_course_section'
        ordering = ['-created_at']
        verbose_name = 'course学生课件'
        permissions = [
            ('view_all_usercoursesection', '查看所有学生课件'),
            ('view_teach_usercoursessection', '查看所教的学生课件'),
            ('view_child_usercoursesection', '查看亲子学生课件'),
            ('pass_ucs_super', '能无条件通过学生课件'),
            ('pass_ucs', '能通过学生课件'),  # 达到要求后才能通过
            ('close_ucs', '能关闭学生课件'),
            ('open_ucs', '能开启学生课件'),
            ('minus_live_mins', '能扣减学生直播时长'),
            ('review_ucs', '能查看学生作业'),
            ('score_ucs', '能给学生作业评分'),
        ]

    def close(self):
        self.status = 0
        self.work_time = 0
        self.score = 0
        self.comment = None
        self.updated_at = timezone.now()
        self.save()

    def has_user_finished_this_video(self, video_id):
        check_list = UserCourseSectionVideo.objects.filter(user_course_section=self, video_id=video_id)
        if check_list.exists():
            return True
        else:
            return False

    def pass_check(self, check_certify=True):
        section = self.section

        # 找到最近通过的UCS，检查在指定的间隔天数里，是否有通过的课程
        if section.pass_cooldown != 0:
            latest_passed_ucs = UserCourseSection.objects.filter(user_course=self.user_course, status=2).order_by(
                '-passed_at')
            if latest_passed_ucs.exists():
                pass_date = latest_passed_ucs.first().passed_at
                if not pass_date:
                    return False
                timedelta = (timezone.now().date() - pass_date.date()).days
                if timedelta < section.pass_cooldown:
                    return False

        if section.has_imagework:
            image_count = self.userassignmentimage_set.count()
            if image_count < section.image_count_req:
                return False

        if section.has_videowork:
            if self.work_time - self.minus_live_mins < section.video_length_req + self.teacher_add_mins:
                return False

        if section.has_questionwork:
            if not self.question_passed:
                return False

        if section.has_to_finish_course_video:
            return self.check_video_watch_status()

        if section.has_textwork:
            if not self.userassignment_set.exists():
                return False

        if check_certify:
            if not self.check_certify_pass() == True:
                return False

        # 所有检查条件都通过，才可自动通过
        return True

    def auto_pass_check(self):
        if not self.section.auto_pass:
            return False

        return self.pass_check(check_certify=True)

    def open_ucs(self):
        # 如果课件为自动通过 先检查是否满足通过条件
        rc = self.auto_pass_check()

        if rc:
            self.get_pass()
        else:
            self.status = 1
            self.learned_at = timezone.now()
            self.updated_at = timezone.now()
            self.save()

    def is_learning(self):
        return self.status == 1

    def is_passed(self):
        return self.status == 2

    def is_rejected(self):
        return self.status == 3

    def is_submit(self):
        return self.status == 4

    def be_submit(self):
        self.updated_at = timezone.now()
        self.save()

    def is_tip(self):
        if self.section.type == 1:
            return True
        else:
            return False

    @transaction.atomic
    def get_pass(self, score=0, comment=None):
        if self.status == 2:  # 避免重复操作
            return

        self.score = score
        self.comment = comment
        if not self.learned_at:
            self.learned_at = timezone.now()
        self.passed_at = timezone.now()
        self.updated_at = timezone.now()
        self.status = 2
        self.save()

        # 发送通过的信号
        ucs_passed.send(sender=UserCourseSection, user_course_section=self)

        # 检查是否还有其他开启的课程
        learning_ucs = self.user_course.usercoursesection_set.filter(status=1)
        if learning_ucs.count() == 0:
            # 自动开启下一课
            next_section = self.next_section()
            if next_section:
                next_section.open_ucs()
            else:
                self.user_course.get_pass()  # 所有课程都通过了，则此课学习完成，通过

    @transaction.atomic
    def reject(self):
        self.score = None
        self.updated_at = timezone.now()
        self.comment = None
        self.status = 3
        self.save()

    def update_work_time(self, minutes):
        if not self.work_time:
            self.work_time = 0
        self.work_time += minutes
        self.save()

        # 检查是否可以自动通过
        rc = self.auto_pass_check()
        if rc:
            self.get_pass()

    # 如果有直播需要，则计算时间倍数，给各个项目独立使用
    # 1倍：发消息 2倍：发邮件
    def get_time_multiple(self):
        if not self.section.has_videowork:
            return 0
        work_time = self.work_time - self.minus_live_mins
        req_time = self.section.video_length_req
        if req_time > 0:
            return work_time / req_time
        else:
            return 0

    def next_section(self, is_open=False):
        order_sets = CourseSectionMid.objects.filter(course=self.user_course.course,
                                                     section=self.section)
        if order_sets.exists():
            order = order_sets.first().order_by
            mids = CourseSectionMid.objects.filter(course=self.user_course.course, order_by__gt=order)
            if mids.exists():
                mid = mids.first()
                if is_open:
                    ucs = UserCourseSection.objects.filter(user_course=self.user_course,
                                                           status__in=[1, 2, 3, 4],
                                                           section=mid.section)
                else:
                    ucs = UserCourseSection.objects.filter(user_course=self.user_course, section=mid.section)
                if ucs.exists():
                    return ucs.first()
                else:
                    return None
            else:
                return None
        else:
            return None

    def get_section_mid_prename(self):
        try:
            mid = CourseSectionMid.objects.get(course=self.user_course.course, section=self.section)
            return mid.pre_name
        except:
            return None

    def get_section_mid_points(self):
        try:
            mid = CourseSectionMid.objects.get(course=self.user_course.course, section=self.section)
            return mid.points
        except:
            return 0

    # 获取学生已通过的课件
    @classmethod
    def get_user_pass_sections(cls, user_course):
        return cls.objects.filter(user_course=user_course, status=2)

    # 获取某时间段内学生学的最后一个课件
    @classmethod
    def get_user_last_course_section(cls, user, start_dt=None, end_dt=None):
        ucs_list = cls.objects.filter(user_course__user=user).order_by('-updated_at')
        if ucs_list.exists():
            if start_dt:
                ucs_list = ucs_list.filter(updated_at__gte=start_dt)
            if end_dt:
                ucs_list = ucs_list.filter(updated_at__lte=end_dt)
            list = ucs_list.filter(status=1)
            if list.exists():
                return list.first()
            else:
                finished = ucs_list.filter(status__in=[2, 4])
                if finished.exists():
                    return finished.first()
                else:
                    return None
        else:
            return None

    def get_section_name(self):
        return self.section.name

    def get_course_name(self):
        return self.user_course.course.name

    def get_punch(self):
        return self.user_course.get_user_course_punch_count()

    def get_course_punch(self):
        return self.user_course.course.punch_duration

    def get_assignment_img_count(self):
        return self.userassignmentimage_set.count()

    def check_video_watch_status(self):
        for e in self.section.sectionvideo_set.all():
            if not self.has_user_finished_this_video(e.video.id):
                return False
        return True

    def is_open_certify(self):
        if not self.section.need_certify:
            return False
        records = self.usercertifyrecord_set.filter(status__in=[0, 1, 2])
        if records.exists():
            return False
        # 其他要求的检查
        r = self.pass_check(check_certify=False)
        if not r:
            return False
        return True

    # 认证
    def do_certify(self, userlive=None):
        if not userlive:
            return
        if not self.section.need_certify:
            return
        records = self.usercertifyrecord_set.filter(status=0)
        if records.exists():
            record = records.first()
        else:
            return
        userlive.is_certify = True
        userlive.save()
        record._submit(userlive)

        return

    # 检查认证是否通过
    def check_certify_pass(self):
        if not self.section.need_certify:
            return True
        records = self.usercertifyrecord_set.filter(status=2)
        if records.exists():
            return True
        return False


# 记录用户是否看过课件的某个视频
# 主要给用户看完视频是否自动通过进行判断
class UserCourseSectionVideo(models.Model):
    user_course_section = models.ForeignKey(UserCourseSection)
    video = models.ForeignKey(Video)
    finish_at = models.DateTimeField(default=timezone.now)


class UserAssignment(models.Model):
    user_course_section = models.ForeignKey(UserCourseSection)
    content = models.TextField(verbose_name='正文', null=True, blank=True)  # 文字作业
    created_at = models.DateTimeField(auto_now_add=True)
    score = models.IntegerField(blank=True, null=True, verbose_name='得分')

    class Meta:
        permissions = (
            ('can_review', 'can review'),
        )
        db_table = 'bee_django_course_user_assignment'

    def submit(self):
        self.status = 1
        self.submit_at = timezone.now()
        self.save()

    def reject(self):
        self.status = 2
        self.rejected_at = timezone.now()
        self.save()


# 删除原图，用压缩的图片代替
class UserAssignmentImage(models.Model):
    user_course_section = models.ForeignKey(UserCourseSection, null=True, blank=True)
    image = models.ImageField(verbose_name='图片作业', upload_to='assignments/%Y/%m/%d')
    upload_at = models.DateTimeField(verbose_name='上传时间', auto_now_add=True)

    class Meta:
        db_table = 'bee_django_course_user_assignment_image'


@receiver(post_save, sender=UserAssignmentImage)
def resize_assignment_image_handler(sender, **kwargs):
    assignment_image = kwargs['instance']
    if kwargs['created']:
        resize_assignment_image(assignment_image.image)


class Preference(models.Model):
    how_to_pass = models.IntegerField(verbose_name='课程通过模式', default=0)  # 0 自动， 1 手动


class UserCertifyRecord(models.Model):
    user_course_section = models.ForeignKey(UserCourseSection)
    status = models.IntegerField(verbose_name='状态', choices=((0, '未提交'), (1, '已提交'), (2, '通过'), (3, '驳回'), (4, '关闭'),),
                                 default=0)  # 0 未提交，1 已提交，2 通过，3 驳回，4 关闭(重新录制认证）
    created_at = models.DateTimeField(auto_now_add=True)
    operator = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name='操作者', null=True, blank=True)
    operated_at = models.DateTimeField(null=True, blank=True, verbose_name='操作时间')
    detail = DictField(verbose_name="添加时的详细数据", null=True, blank=True)
    user_live = models.ForeignKey(UserLive, null=True, blank=True)

    class Meta:
        app_label = 'bee_django_course'
        db_table = 'bee_django_course_user_certify_record'
        ordering = ["-id"]

    def get_status(self):
        if self.status == 0:
            return '已开启，未提交'
        elif self.status == 1:
            return '已提交，待认证'
        elif self.status == 2:
            return '已通过'
        elif self.status == 3:
            return '未通过'
        elif self.status == 4:
            return '已关闭'
        else:
            return ''

    @classmethod
    def _create(cls, ucs):
        section = ucs.section
        detail = {}
        # TODO
        if section.has_videowork:
            detail["live_mins"] = ucs.work_time
        cls.objects.create(user_course_section=ucs, status=0, detail=detail)
        return

    def _submit(self, userlive=None):
        self.user_live = userlive
        self.status = 1
        self.save()
        rc = self.user_course_section.auto_pass_check()
        if rc:
            self.user_course_section.get_pass()
        user_certify_update_status.send(sender=self.__class__, user_certify=self, status="submit")

    def _pass(self, operator=None):
        self.status = 2
        self.operator = operator
        self.operated_at = timezone.now()
        self.save()
        # 检查是否可以自动通过
        rc = self.user_course_section.auto_pass_check()
        if rc:
            self.user_course_section.get_pass()
        return

    def _reject(self, operator=None):
        self.status = 3
        self.operator = operator
        self.operated_at = timezone.now()
        if self.user_course_section.section.has_videowork:
            live_mins = self.detail["live_mins"]  # 学生提交时已练时间
            self.user_course_section.teacher_add_mins = live_mins
            self.user_course_section.save()
        self.save()

    def _close(self, operator=None):
        self.status = 4
        self.operator = operator
        self.operated_at = timezone.now()
        self.save()



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-04-01 11:23
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_course', '0024_auto_20180331_1011'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserLive',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('provider_name', models.CharField(max_length=180)),
                ('cc_user_id', models.CharField(max_length=180, null=True)),
                ('room_id', models.CharField(max_length=180, null=True)),
                ('live_id', models.CharField(max_length=180, null=True)),
                ('stop_status', models.CharField(max_length=180, null=True)),
                ('record_status', models.CharField(max_length=180, null=True)),
                ('record_video_id', models.CharField(max_length=180, null=True)),
                ('replay_url', models.CharField(max_length=180, null=True)),
                ('start_time', models.DateTimeField(null=True)),
                ('end_time', models.DateTimeField(null=True)),
                ('duration', models.IntegerField(null=True)),
                ('record_video_duration', models.IntegerField(null=True)),
                ('status', models.IntegerField(default=1, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('call_count', models.IntegerField(default=0)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'user_live',
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-15 06:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0029_auto_20180515_1301'),
    ]

    operations = [
        migrations.CreateModel(
            name='Preference',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('how_to_pass', models.IntegerField(default=0, verbose_name='\u8bfe\u7a0b\u901a\u8fc7\u6a21\u5f0f')),
            ],
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-03-28 07:54
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0020_auto_20180326_1358'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userassignment',
            options={'permissions': (('can_review', 'can review'),)},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-13 09:43
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0064_auto_20190710_1507'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userlive',
            options={'ordering': ['-created_at'], 'permissions': (('view_all_userlives', '\u53ef\u4ee5\u67e5\u770b\u6240\u6709\u5b66\u751f\u7684\u5f55\u64ad'), ('view_teach_userlives', '\u53ef\u4ee5\u67e5\u770b\u6240\u6559\u7684\u5b66\u751f\u7684\u5f55\u64ad'), ('view_child_userlives', '\u53ef\u4ee5\u67e5\u770b\u4eb2\u5b50\u5b66\u751f\u7684\u5f55\u64ad'), ('view_expired_userlives', '\u53ef\u4ee5\u67e5\u770b\u8d85\u8fc7\u6307\u5b9a\u65f6\u95f4\u7684\u5f55\u64ad')), 'verbose_name': 'course\u5b66\u751f\u5f55\u64ad'},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-19 06:14
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0066_auto_20190816_1757'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='usercoursesection',
            options={'ordering': ['-created_at'], 'permissions': [('view_all_usercoursesection', '\u67e5\u770b\u6240\u6709\u5b66\u751f\u8bfe\u4ef6'), ('view_teach_usercoursessection', '\u67e5\u770b\u6240\u6559\u7684\u5b66\u751f\u8bfe\u4ef6'), ('view_child_usercoursesection', '\u67e5\u770b\u4eb2\u5b50\u5b66\u751f\u8bfe\u4ef6'), ('pass_ucs', '\u80fd\u901a\u8fc7\u5b66\u751f\u8bfe\u4ef6'), ('close_ucs', '\u80fd\u5173\u95ed\u5b66\u751f\u8bfe\u4ef6'), ('open_ucs', '\u80fd\u5f00\u542f\u5b66\u751f\u8bfe\u4ef6'), ('minus_live_mins', '\u80fd\u6263\u51cf\u5b66\u751f\u76f4\u64ad\u65f6\u957f'), ('review_ucs', '\u80fd\u67e5\u770b\u5b66\u751f\u4f5c\u4e1a'), ('score_ucs', '\u80fd\u7ed9\u5b66\u751f\u4f5c\u4e1a\u8bc4\u5206')], 'verbose_name': 'course\u5b66\u751f\u8bfe\u4ef6'},
        ),
        migrations.RenameField(
            model_name='usercoursesection',
            old_name='minus_mins',
            new_name='minus_live_mins',
        ),
    ]



# -*- coding: utf-8 -*-
__author__ = 'bee'

import urllib, urllib2, pytz, json, random, datetime
from django.http import HttpResponse
from django.db.models import Count, Sum, Max, Min
from django.db.models.functions import TruncMonth, TruncDay
from django.utils import timezone
from django.conf import settings
from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger

from .models import UserLive, User, UserCourseSection
from bee_django_course import signals
from .dt import LOCAL_TIMEZONE


# =====http====
def http_get(url):
    f = urllib.urlopen(url)
    s = f.read()
    return s


def http_post(url, parameters=None):
    parameters = urllib.urlencode(parameters)
    request = urllib2.Request(url, parameters)
    request.add_header('Content-Type', 'application/x-www-form-urlencoded')
    res_data = urllib2.urlopen(request, timeout=10)
    res = res_data.read()
    return res


# ====dt====
# 获取本地当前时间
def get_now(tz=LOCAL_TIMEZONE):
    return timezone.now()


class JSONResponse(HttpResponse):
    def __init__(self, obj):
        if isinstance(obj, dict):
            _json_str = json.dumps(obj)
        else:
            _json_str = obj
        super(JSONResponse, self).__init__(_json_str, content_type="application/json;charset=utf-8")


def page_it(request, query_set, url_param_name='page', items_per_page=25):
    paginator = Paginator(query_set, items_per_page)

    page = request.GET.get(url_param_name)
    try:
        rs = paginator.page(page)
    except PageNotAnInteger:
        rs = paginator.page(1)
    except EmptyPage:
        rs = paginator.page(paginator.num_pages)

    return rs


# 获取用户姓名
def get_user_name(user):
    try:
        user_name = getattr(user, settings.USER_NAME_FIELD)
    except:
        user_name = user.username
    return user_name


# 返回直播分钟数，直播次数，直播天数
def get_user_live_data(user, start_dt=None, end_dt=None):
    vod_list = UserLive.objects.filter(status__in=[1, 2]).filter(user=user).filter(record_status=10)
    if start_dt:
        vod_list = vod_list.filter(start_time__gte=start_dt)
    if end_dt:
        vod_list = vod_list.filter(start_time__lt=end_dt)
    if vod_list.count() == 0:
        return 0, 0, 0
    res_mins = vod_list.aggregate(
        sum_duration=Sum('duration'))
    days_qurey_set = vod_list.annotate(day=TruncDay('start_time', tzinfo=LOCAL_TIMEZONE)).values('day') \
        .annotate(count=Count('id'), total=Sum('duration')).values('day', 'count', 'total') \
        .order_by('day')
    days_count = days_qurey_set.count()
    return res_mins["sum_duration"] / 60, vod_list.count(), days_count


# 某人是否可以观看视频，观看视频后是否能被记录为【助教已观看】。
# 条件1：有权限，条件2：录制本人，条件3：超过48小时。
def can_view_expired_live(user, user_live):
    # 本人可看，但不记入观看
    if user == user_live.user:
        return True, False

    # 判断是否助教
    is_mentor = user.is_user_assistant(user_live.user)

    # 设置过期时间
    if hasattr(settings, "COURSE_LIVE_EXPIRED_HOURS"):
        expired_dt = user_live.start_time + datetime.timedelta(hours=settings.COURSE_LIVE_EXPIRED_HOURS)
        # 未过期
        if timezone.now() < expired_dt:
            if is_mentor:
                return True, True
            else:
                return True, False
        # 已过期
        else:
            if user.has_perm('bee_django_course.view_expired_userlives'):
                return True, False
            else:
                return False, False
    # 未设置过期时间
    else:
        if is_mentor:
            return True, True
        else:
            return True, False


# from .views import live_finish

from gensee import vod_sync


def gensee_vod_sync(day=0):
    page = 1
    totalPages = 1
    sync_count = 0
    while page <= totalPages:
        vod_list_res = vod_sync(page=page, day=day)
        try:
            if not vod_list_res["code"] == "0":
                return
        except:
            return
        totalPages = vod_list_res["page"]["totalPages"]
        vod_list = vod_list_res["list"]
        page += 1
        for i, v in enumerate(vod_list):
            user_live = save_gensee_live(v)
            if user_live:
                live_finish(user_live)
                sync_count += 1
    return sync_count


def save_gensee_live(vod):
    live_id = vod["id"]  # 点播ID
    room_id = vod["webcastId"]  # 直播ID
    res = UserLive.objects.filter(live_id=live_id)
    # 重复
    if res.exists():
        return False
    # 不是学生录播
    if not vod["creator"] == 30196111:
        return False
    # 找不到对应学生
    try:
        user = User.objects.get(userprofile__gensee_room_id=room_id)
    except:
        return False
    try:
        user_live = UserLive()
        user_live.provider_name = 'gensee'
        user_live.room_id = room_id  # 直播ID
        user_live.live_id = live_id  # 点播ID
        user_live.stop_status = 10
        user_live.record_status = 10
        start_time = LOCAL_TIMEZONE.localize(datetime.datetime.fromtimestamp(int(vod["recordStartTime"] / 1000)))
        end_time = LOCAL_TIMEZONE.localize(datetime.datetime.fromtimestamp(int(vod["recordEndTime"] / 1000)))
        user_live.record_video_id = vod["recordId"]  # 该点播使用的录制件ID
        user_live.replay_url = vod["attendeeJoinUrl"]  # 加入URL
        user_live.start_time = start_time  # 录制开始时间
        user_live.end_time = end_time  # 录制结束时间
        user_live.duration = int(vod["duration"] / 1000)  # 内容时长。单位是毫秒。
        user_live.user = user
        user_live.save()
        return user_live
    except Exception as e:
        print (e)
        return False


def update_live_mins(user):
    live_set = user.userlive_set.filter(record_status='10', status__in=[1, 2])
    total_mins = 0
    for e in live_set:
        if e.duration > 60:
            min = e.duration / 60
            total_mins += min
    if hasattr(user, 'set_live_mins'):
        user.set_live_mins(total_mins)


# 直播转码完成后的一系列操作：更新课件进度，发送信号
def live_finish(userlive, timedelta=None):
    if not timedelta:
        timedelta = userlive.duration
    if timedelta < 60:
        return

    if not userlive.user:
        return

    # 更新课件学习时间
    user_course_section = UserCourseSection.get_user_last_course_section(userlive.user)
    if user_course_section:
        user_course_section.update_work_time(timedelta / 60)
        signals.ucs_update_time.send(sender=UserCourseSection, ucs=user_course_section)
        update_live_mins(userlive.user)

        # 需认证课件
        if user_course_section.section.need_certify:
            user_course_section.do_certify(userlive)


    coin_multiple = save_coin_multiple(userlive)
    signals.live_callback_finished.send(sender=UserLive, user_live=userlive, coin_multiple=coin_multiple)
    return


def save_coin_multiple(userlive):
    coin_multiple = 1
    r = random.randint(1, 1000)
    if r >= 980:
        coin_multiple = 3
    elif r >= 900:
        coin_multiple = 2
    userlive.coin_multiple = coin_multiple
    userlive.save()
    return coin_multiple



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-12 07:55
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0074_auto_20191012_1414'),
    ]

    operations = [
        migrations.AlterField(
            model_name='course',
            name='punch_period',
            field=models.IntegerField(blank=True, choices=[(1, '\u5929')], help_text='\u7528\u4e8e\u8bfe\u7a0b\u6253\u5361\uff0c\u5982\u4e0d\u9700\u8981\u53ef\u4e0d\u586b\u5199', null=True, verbose_name='\u5468\u671f'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-21 06:43
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0060_auto_20181219_1353'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='sectionquestion',
            options={'ordering': ['order_by'], 'permissions': (('view_sectionquestion', '\u53ef\u4ee5\u67e5\u770b\u95ee\u9898\u5217\u8868'),)},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-09-06 07:38
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0049_sectionquestion_sectionquestionoption'),
    ]

    operations = [
        migrations.AddField(
            model_name='sectionquestion',
            name='options',
            field=models.ManyToManyField(to='bee_django_course.SectionQuestionOption'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-21 06:00
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0033_auto_20180517_1937'),
    ]

    operations = [
        migrations.CreateModel(
            name='SectionAttach',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file', models.FileField(upload_to='sections/%Y/%m/%d/', verbose_name='\u9644\u4ef6')),
                ('upload_at', models.DateTimeField(auto_now_add=True)),
                ('section', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.Section')),
            ],
        ),
        migrations.AddField(
            model_name='course',
            name='status',
            field=models.IntegerField(default=0, verbose_name='\u72b6\u6001'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-21 07:18
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0075_auto_20191012_1555'),
    ]

    operations = [
        migrations.AddField(
            model_name='section',
            name='has_to_finish_course_video',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u9700\u8981\u770b\u5b8c\u8bfe\u4ef6\u6240\u6709\u89c6\u9891'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.test import TestCase
from bee_django_course.models import Course, Section, UserCourseSection, CourseSectionMid

# Create your tests here.

def create_user(name):
    pass

def create_course(name):
    return Course.objects.create(name=name)

def create_section(name):
    return Section.objects.create(name=name)


class UserCourseSectionTest(TestCase):
    def setUp(self):
        # 创建 course
        course = create_course('test_course')
        # 创建 section
        for i in range(0,5):
            section = create_section(name='section'+str(i))
            CourseSectionMid.objects.create(course=course, section=section, order_by=i)

        # 创建用户
        # 分配课程

    def video_length_section_automatic_pass(self):
        pass


# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-17 10:48
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0031_auto_20180516_1714'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='course',
            options={'ordering': ['-id'], 'permissions': (('can_manage_course', '\u53ef\u4ee5\u8fdb\u5165\u8bfe\u7a0b\u7ba1\u7406\u9875'), ('can_choose_course', 'can choose course')), 'verbose_name': 'course\u8bfe\u7a0b'},
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'zhangyue'

from django import template
from django.conf import settings
from django.shortcuts import reverse
from bee_django_course.models import UserQuestionAnswerRecord,UserLive,UserCourseSection
from bee_django_course.exports import filter_local_datetime
from bee_django_course.utils import get_user_name
from bee_django_course.views import get_user_last_course_section

from bee_django_course.qiniu_api import get_video_str as _get_qiniu_video_str
from bee_django_course.cc import get_video_str as _get_cc_video_str
register = template.Library()


# 本地化时间
@register.filter
def local_datetime(_datetime):
    return filter_local_datetime(_datetime)


# 求两个值的差的绝对值
@register.filter
def get_difference_abs(a, b):
    return abs(a - b)


# 获取视频供应商的名字
@register.filter
def get_video_provider_name():
    return settings.COURSE_VIDEO_PROVIDER_NAME


# CC点播视频播放地址
@register.filter
def get_video_src(video_id):
    return _get_cc_video_str(video_id)

# 七牛云视频播放地址
@register.filter
def get_qiniu_video_src(file_name):
    return _get_qiniu_video_str(file_name)


# 用户是否学了此课程
@register.simple_tag
def has_course(user, course):
    return course.is_my_course(user)


# 课程显示状态
@register.simple_tag
def course_status(status):
    if status == 0:
        return '显示'
    else:
        return '不显示'


# 用户课程学习状态，user_course_section.status -> 文字
# 0 未开始， 1 学习中，2 通过，3 退回重修, 4 提交
@register.filter
def course_status(status):

    if status == 0:
        rc = '未开始'
    elif status == 1:
        rc = '学习中'
    elif status == 2:
        rc = '通过'
    elif status == 3:
        rc = '退回重修'
    elif status == 4:
        rc = '提交'
    else:
        rc = ''

    return rc

# 获取学生姓名，及详情链接
@register.filter
def get_name_detail(user, show_detail=True):
    user_name = get_user_name(user)
    if not show_detail:
        return user_name
    if settings.USER_DETAIL_EX_LINK:
        link = "<a href='" + settings.USER_DETAIL_EX_LINK + user.id.__str__() + "/'>" + user_name + "</a>"
    else:
        link = user_name
    return link


# 显示课件类型
@register.filter
def section_type(type):
    if type == 0:
        return '普通课件'
    elif type == 1:
        return 'TIPS'


# 秒变分钟
@register.filter
def seconds_to_minutes(s):
    return s/60


# 获取用户最新学习课程，以及练习情况
@register.simple_tag
def current_user_course_section(user):
    ucs = get_user_last_course_section(user)
    return ucs


# 学生下一个能学的课件
@register.simple_tag
def next_user_course_section(ucs):
    next_ucs = ucs.next_section(is_open=True)
    return next_ucs


# 学生的答案
@register.simple_tag
def get_user_question_answer(question,user):
    return UserQuestionAnswerRecord.get_user_question_answer_options(question,user)


# 用户是否观看了这段课程视频
@register.simple_tag
def has_user_watched_this_video(ucs, video_id):
    return ucs.has_user_finished_this_video(video_id)

# 获取学生的录播报表
@register.simple_tag
def get_user_live_report(user,start_dt,end_dt):
    return UserLive.get_user_live_report([user],start_dt,end_dt)

# 获取学生的进度
@register.simple_tag
def get_user_last_course_section(user, start_dt, end_dt):
    return UserCourseSection.get_user_last_course_section(user,start_dt,end_dt)


#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'


from django.conf import settings

class Gensee():

    genseeUrl = "http://zenweiqi.gensee.com/integration/site"
    student_password = "manxuetang!"
    student_organizerToken = '111111'
    student_panelistToken = '222222'

    class gensee_admin_account:
        username = "admin@zenweiqi.com"
        password = "888888"


    class gensee_manke_account:
        username = "manke@zhenpuedu.com"
        password = "manxuetang123"


    class gensee_stage_account:
        username = "stage@zenweiqi.com"
        password = '111111'

class CC():
    user_id = '116A0DDBD5490C3E'
    live_apikey = "xJSsamNrYlfun55MksEMHcHM9DG6xdyt"
    video_apikey = "lL9ZS4sRgi7GoHW5BFukFk7ZInQOgW86"
    player_id = '73713B694B1A64E3'
    category_id = '3782E07C245BB580'
    video_callback_url = ''

class Qiniu():
    ak='w4yaDe9SPuChxJHBQnefqlond1704XS4vHU_3sMK'
    sk='stoLiR-4tCV7v0A51S-ly4fFJgNWI_b0USdQccua'
    bucket_name='xinanxiangju-video'
    domain='video.xinanxiangju.com'

class Tencent():
    live_key="8ea93cf8031d0802fbcb30bf406b0624"



# ======初始化========
def init_settings():
    # cc
    if "cc" in settings.COURSE_LIVE_PROVIDER_LIST or "cc" == settings.COURSE_VIDEO_PROVIDER_NAME:
        settings.CC_CONFIG=CC()

    # qiniu
    if "qiniu" == settings.COURSE_VIDEO_PROVIDER_NAME:
        settings.QINIU_CONFIG=Qiniu()
    #
    # gensee
    if "gensee" in settings.COURSE_LIVE_PROVIDER_LIST:
        settings.GENSEE_CONFIG=Gensee()

    if "tencent" in settings.COURSE_LIVE_PROVIDER_LIST:
        settings.TENCENT_CONFIG=Tencent()



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-09-11 07:49
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0071_userlive_is_mentor_view'),
    ]

    operations = [
        migrations.AddField(
            model_name='userlive',
            name='view_mentor_id',
            field=models.IntegerField(null=True),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-

__author__ = 'bee'
import unicodecsv as csv
from django.http import StreamingHttpResponse

# 导出csv
def export_csv(filename, headers, rows):
    response = StreamingHttpResponse((row for row in csv_itertor(headers, rows)), content_type="text/csv;charset=utf-8")
    response['Content-Disposition'] = 'attachment;filename="' + filename + '.csv"'
    return response


def csv_itertor(headers, rows):
    pseudo_buffer = Echo()
    writer = csv.writer(pseudo_buffer)
    yield writer.writerow(headers)
    for column in rows:
        yield writer.writerow(column)


class Echo(object):
    """An object that implements just the write method of the file-like
    interface.
    """

    def write(self, value):
        """Write the value by returning it, instead of storing in a buffer."""
        return value


# 完


# -*- coding:utf-8 -*-
import time, datetime
from django.core.management.base import BaseCommand
from bee_django_course.models import UserAssignmentImage
from django.utils import timezone

class Command(BaseCommand):

    def add_arguments(self, parser):
        parser.add_argument('days', type=int, nargs='?', default=90)

    def handle(self, *args, **options):
        # 默认删除2个月前传的图片
        days = options["days"]
        for e in UserAssignmentImage.objects.filter(upload_at__lt=timezone.now() - datetime.timedelta(days=days)):
            e.image.delete()
            # 只删除图片，保留model记录

        return



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'

import json, os, math, calendar, urllib, hashlib
from django.conf import settings
from utils import http_get, get_now, JSONResponse
from .models import Video
# moment.apis import get_user_moment_count
from django.shortcuts import render, render_to_response
from django.http import HttpResponse, HttpRequest
from django.template import RequestContext
from django.core.urlresolvers import reverse
from django.http import HttpResponseRedirect
from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
from django.core.files.storage import default_storage
from django.core.files.base import ContentFile


# 创建工作室的分类
# 包括以名字命命的一级目录和两个二级目录
def create_studio_category(name):
    category_id = create_category(name)
    category_video_id = category_live_id = None
    if category_id:
        category_video_id = create_category(name + u"-课程", category_id)
        category_live_id = create_category(name + u"-直播", category_id)
    return category_id, category_live_id, category_video_id


# 修改工作室分类
def update_studio_category(category_id, name):
    update_category(category_id, name)
    return


# 创建分类
# super_categoryid为空，创建一级目录
def create_category(category_name, super_categoryid=None):
    # http://doc.bokecc.com/vod/dev/SparkAPI/spark10/
    if not hasattr(settings, "CC_CONFIG"):
        return
    url = "http://spark.bokecc.com/api/category/create"
    params_dict = {
        "userid": settings.CC_CONFIG.user_id,
        "name": category_name.encode('utf-8'),
        "format": "json"
    }
    if super_categoryid:
        params_dict["super_categoryid"] = super_categoryid

    qs = thqs(params_dict, 'video')
    url += "?" + qs
    res = http_get(url)
    res_json = str2json(res)
    if res_json:
        if res_json.has_key("category"):
            return res_json["category"]["id"]
    return None


# 编辑视频分类,重命名等
def update_category(category_id, category_name):
    # http://spark.bokecc.com/api/category/update
    # http://doc.bokecc.com/vod/dev/SparkAPI/spark10/
    if not hasattr(settings, "CC_CONFIG"):
        return
    url = "http://spark.bokecc.com/api/category/update"
    params_dict = {
        "categoryid": category_id,
        "userid": settings.CC_CONFIG.user_id,
        "name": category_name.encode('utf-8'),
        "format": "json"
    }

    qs = thqs(params_dict, 'video')
    url += "?" + qs
    http_get(url)
    return


# 创建直播间
def create_room(room_name):
    # http://doc.bokecc.com/live/dev/liveapi/#toc_11
    if not hasattr(settings, "CC_CONFIG"):
        return
    url = "http://api.csslcloud.net/api/room/create"
    params_dict = {
        "userid": settings.CC_CONFIG.user_id,
        "name": room_name.encode('utf-8'),
        "desc": room_name.encode('utf-8'),
        "templatetype": "1",
        "authtype": "2",
        "publisherpass": "111111",
        "assistantpass": "222222",
        "barrage": "0",
        "foreignpublish": "0"
    }
    qs = thqs(params_dict, 'live')
    url += "?" + qs
    try:
        res = http_get(url)
        res_json = str2json(res)
        if res_json:
            if res_json.has_key("result"):
                if res_json["result"] == 'OK':
                    return res_json["room"]["id"]
    except:
        return None
    return None


# 关闭直播间
def close_room(room_id):
    # https://doc.bokecc.com/live/live_http.html
    if not hasattr(settings, "CC_CONFIG"):
        return
    url = "http://api.csslcloud.net/api/room/close"
    params_dict = {
        "userid": settings.CC_CONFIG.user_id,
        "roomid": room_id

    }
    qs = thqs(params_dict, 'live')
    url += "?" + qs
    res = http_get(url)
    res_json = str2json(res)
    if res_json:
        if res_json.has_key("result"):
            return True
    return None

# 开启直播间
def open_room(room_id):
    if not hasattr(settings, "CC_CONFIG"):
        return
    url = "http://api.csslcloud.net/api/room/open"
    params_dict = {
        "userid": settings.CC_CONFIG.user_id,
        "roomid": room_id

    }
    qs = thqs(params_dict, 'live')
    url += "?" + qs
    res = http_get(url)
    res_json = str2json(res)
    if res_json:
        if res_json.has_key("result"):
            return True
    return None


# 获取直播间代码
def get_room_code(room_id):
    # http://doc.bokecc.com/live/dev/liveapi/#toc_22
    if not hasattr(settings, "CC_CONFIG"):
        return
    url = "http://api.csslcloud.net/api/room/code"
    params_dict = {
        "roomid": room_id,
        "userid": settings.CC_CONFIG.user_id
    }
    qs = thqs(params_dict, 'live')
    url += "?" + qs
    res = http_get(url)
    res_json = str2json(res)
    if res_json:
        if res_json.has_key("result"):
            if res_json["result"] == 'OK':
                return res_json
    return None



# 1.创建视频上传信息
def create_video_info(title, filename, filesize, categoryid=None):
    # http://doc.bokecc.com/vod/dev/uploadAPI/upload02/
    if not hasattr(settings, "CC_CONFIG"):
        return
    url = "http://spark.bokecc.com/api/video/create"
    if not categoryid:
        categoryid=settings.CC_CONFIG.category_id
    params_dict = {
        "userid": settings.CC_CONFIG.user_id,
        "title": title.encode('utf-8'),
        "description": filename.encode('utf-8'),
        "categoryid": categoryid,
        "filesize": filesize,
        "notify_url": settings.CC_CONFIG.video_callback_url.encode('utf-8'),
        "format": "json",

    }
    qs = thqs(params_dict, 'video')
    url += "?" + qs
    res = http_get(url)
    res_json = str2json(res)
    if res_json.has_key(u"uploadinfo"):
        return res_json
    return None


# 2 上传成功后记录用户video对应关系
def uplode_video_done(request):
    uid = request.POST.get("uid")
    title = request.POST.get("title")
    print('uplode_video_done', uid)
    if title:
        title = os.path.splitext(title)[0]
    videoid = request.POST.get("videoid")
    if videoid:
        ccvideo = Video()
        ccvideo.title = title
        ccvideo.created_by = request.user
        ccvideo.videoid = videoid
        ccvideo.save()
    res = {"error": 0}
    return JSONResponse(json.dumps(res, ensure_ascii=False))




# 获取直播回放记录
def get_live_watched():
    # http://doc.bokecc.com/live/dev/liveapi/#toc_26
    if not hasattr(settings, "CC_CONFIG"):
        return
    url = "http://api.csslcloud.net/api/statis/replay"
    now = get_now()
    params_dict = {
        "userid": settings.CC_CONFIG.user_id,
        "starttime": "2017-07-27 15:00",
        "endtime": "2017-07-27 19:00",
        "pageindex": "1",
        "pagenum": "50",

    }
    qs = thqs(params_dict, 'live')
    url += "?" + qs
    res = http_get(url)
    print(res)
    res_json = str2json(res)
    print(res_json)


# 未使用
# 获取视频播放代码
def get_video_play_code(videoid):
    # http://doc.bokecc.com/vod/dev/SparkAPI/spark06/
    if not hasattr(settings, "CC_CONFIG"):
        return
    url = "http://spark.bokecc.com/api/video/playcode"
    params_dict = {
        "videoid": videoid,
        "userid": settings.CC_CONFIG.user_id,
        "player_width": "100%",
        "player_height": "40%",
        "auto_play": "true",
        "format": "json",

    }
    qs = thqs(params_dict, 'live')
    url += "?" + qs
    # print(url)
    res = http_get(url)
    # print(res)
    res_json = str2json(res)
    # print(res_json)
    return


# 获取点播视频播放地址
def get_video_str(video_id):
    if not hasattr(settings, "CC_CONFIG"):
        return
    src = "https://p.bokecc.com/playhtml.bo?vid=" + video_id + "&siteid=" + settings.CC_CONFIG.user_id + "&autoStart=false&playerid=" + settings.CC_CONFIG.player_id + "&playertype=1"
    return src

# 获取录播视频地址
def get_live_str(video_id):
    if not hasattr(settings, "CC_CONFIG"):
        return
    url="http://p.bokecc.com/api/mobile"
    params_dict = {
        "videoid": video_id,
        "userid": settings.CC_CONFIG.user_id,
        "format": "json",
        "httpsflag":1,
        "hlsflag":0,
    }
    qs = thqs(params_dict, 'video')
    url += "?" + qs
    res = http_get(url)
    res_json = str2json(res)
    if res_json.has_key("error"):
        return None
    return res_json["video"]["copy"][0]["playurl"]


# 删除视频
def delete_video(vodio_id):
    # http://doc.bokecc.com/vod/dev/SparkAPI/spark08/
    if not hasattr(settings, "CC_CONFIG"):
        return
    url = "http://spark.bokecc.com/api/video/delete"
    params_dict = {
        "userid": settings.CC_CONFIG.user_id,
        "videoid": vodio_id,
        "format": "json",

    }
    qs = thqs(params_dict, 'video')
    url += "?" + qs
    res = http_get(url)
    res_json = str2json(res)
    if res_json.has_key(u"result"):
        if res_json["result"] == 'OK':
            return True
    return



# 获取某条视频某日的观看记录
# def get_video_play_logs(video_id, date):
#     # https://doc.bokecc.com/index.php?c=content&a=list&catid=295
#     url = "http://spark.bokecc.com/api/playlog/video/v2"
#     params_dict = {
#         "userid": settings.COURSE_CC_USERID,
#         "videoid": video_id,
#         "date": date,
#         "num_per_page": 5000,
#         "page": 1
#     }
#     qs = thqs(params_dict, 'video')
#     url += "?" + qs
#     res = http_get(url)
#     res_json = str2json(res)
#     if res_json.has_key(u"total") and res_json.has_key(u"play_log"):
#         return res_json["total"], res_json["play_log"]
#     return None, None


# 获取日期内全部视频的观看记录
# def get_play_logs(date):
#     # https://doc.bokecc.com/index.php?c=content&a=list&catid=315
#     url = "http://spark.bokecc.com/api/playlog/user/v2"
#     params_dict = {
#         "userid": settings.COURSE_CC_USERID,
#         "date": date,
#         "num_per_page": 5000,
#         "page": 1
#     }
#     qs = thqs(params_dict, 'video')
#     url += "?" + qs
#     res = http_get(url)
#     res_json = str2json(res)
#     if res_json.has_key(u"total") and res_json.has_key(u"play_log"):
#         return res_json["total"], res_json["play_log"]
#     return None, None


# =================

def get_timestamp(_datetime):
    timestamp = calendar.timegm(_datetime.utctimetuple())
    return timestamp



def thqs(params, type_str):
    # http://doc.bokecc.com/live/dev/liveapi/#toc_39
    if not hasattr(settings, "CC_CONFIG"):
        return
    qs = ""
    if type_str == 'live':
        salt = settings.CC_CONFIG.live_apikey
    else:
        salt = settings.CC_CONFIG.video_apikey

    if params and len(params) > 0:
        sortd_params = sorted(params.iteritems(), key=lambda item: item[0])
        qs = urllib.urlencode(sortd_params)

    timestamp = get_timestamp(get_now())

    qf = qs
    if len(qf) > 0:
        qf = "%s&" % qf
    qf = "%stime=%d&salt=%s" % (qf, timestamp, salt)

    qmd5 = hashlib.md5(qf).hexdigest()
    hqs = qs
    if len(hqs) > 0:
        hqs = "%s&" % hqs
    hqs = "%stime=%d&hash=%s" % (hqs, timestamp, qmd5)

    return hqs



# 结果转json
def str2json(res):
    try:
        res_json = json.loads(res)
    except:
        res_json = None
    return res_json



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-19 05:53
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0059_userquestionanswerrecord'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='usercourse',
            options={'permissions': [('assign_user_course', '\u80fd\u7ed9\u5b66\u751f\u5206\u914d\u8bfe\u7a0b')]},
        ),
        migrations.AlterModelOptions(
            name='usercoursesection',
            options={'ordering': ['-created_at'], 'permissions': [('view_all_usercoursesection', '\u67e5\u770b\u6240\u6709\u5b66\u751f\u8bfe\u4ef6'), ('view_teach_usercoursessection', '\u67e5\u770b\u6240\u6559\u7684\u5b66\u751f\u8bfe\u4ef6'), ('pass_ucs', '\u80fd\u901a\u8fc7\u5b66\u751f\u8bfe\u4ef6'), ('close_ucs', '\u80fd\u5173\u95ed\u5b66\u751f\u8bfe\u4ef6'), ('open_ucs', '\u80fd\u5f00\u542f\u5b66\u751f\u8bfe\u4ef6'), ('review_ucs', '\u80fd\u67e5\u770b\u5b66\u751f\u4f5c\u4e1a'), ('score_ucs', '\u80fd\u7ed9\u5b66\u751f\u4f5c\u4e1a\u8bc4\u5206')], 'verbose_name': 'course\u5b66\u751f\u8bfe\u4ef6'},
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'
import json, datetime
from django.utils import timezone
from django.conf import settings
from utils import http_post
from dt import get_now, get_datetime_with_scope_offset, LOCAL_TIMEZONE


# 获取直播间id
def create_room(room_name):
    if not hasattr(settings, "GENSEE_CONFIG"):
        return
    create_webcast_parameters = {
        "subject": room_name.encode('utf-8'),
        "startTime": timezone.now(),
        "organizerToken": settings.GENSEE_CONFIG.student_organizerToken,
        "panelistToken": settings.GENSEE_CONFIG.student_panelistToken,
        "attendeeToken": "",
        "loginName": settings.GENSEE_CONFIG.gensee_manke_account.username,
        "password": settings.GENSEE_CONFIG.gensee_manke_account.password
    }
    create_webcast_res = gensee_api_post("/webcast/created", create_webcast_parameters)
    if create_webcast_res and create_webcast_res["code"] == "0":
        return create_webcast_res["id"]
    else:
        return None


# 删除直播间
def delete_room(room_id):
    if not hasattr(settings, "GENSEE_CONFIG"):
        return
    delete_webcast_parameters = {
        "webcastId": room_id,
        "loginName": settings.GENSEE_CONFIG.gensee_manke_account.username,
        "password": settings.GENSEE_CONFIG.gensee_manke_account.password
    }
    create_webcast_res = gensee_api_post("/webcast/deleted", delete_webcast_parameters)
    if create_webcast_res and create_webcast_res["code"] == "0":
        return True
    else:
        return False


# 获取直播间信息
def get_room_info(room_id):
    if not hasattr(settings, "GENSEE_CONFIG"):
        return
    live_webcast_res = gensee_api_post("/webcast/setting/info",
                                       {"webcastId": room_id, "loginName":
                                           settings.GENSEE_CONFIG.gensee_manke_account.username,
                                        "password": settings.GENSEE_CONFIG.gensee_manke_account.password})
    if live_webcast_res["code"] == "0":
        room = live_webcast_res
    else:
        room = None
    return room


def gensee_api_post(url, parameters):
    if not hasattr(settings, "GENSEE_CONFIG"):
        return
    url = settings.GENSEE_CONFIG.genseeUrl + url
    res = http_post(url, parameters)
    try:
        j = json.loads(res)
    except Exception as e:
        print(e)
        j = None
    return j


# 同步gensee的录播记录  /webcast/vod/sync
# 分页获取本站点中已发布的点播数据。每页最大返回 50 条数据
# 该 API 要求认证用户具有管理员角色。
def vod_sync(page=1, day=0):
    if not hasattr(settings, "GENSEE_CONFIG"):
        return
    now = get_now()
    # 取前一天数据
    if day == -1:
        start_dt, end_dt = get_datetime_with_scope_offset("day", -1)

        # yesterday = now - datetime.timedelta(days=1)
        # y_year = yesterday.strftime("%Y")
        # y_month = yesterday.strftime("%m")
        # y_day = yesterday.strftime("%d")
        # # t_year = now.strftime("%Y")
        # # t_month = now.strftime("%m")
        # # t_day = now.strftime("%d")
        # start_time_str = y_year + '-' + y_month + "-" + y_day + " 00:00:00"
        # end_time_str = y_year + '-' + y_month + "-" + y_day + " 23:59:59"
        # startTime = datetime.datetime.strptime(start_time_str, "%Y-%m-%d %H:%M:%S")
        # endTime = datetime.datetime.strptime(end_time_str, "%Y-%m-%d %H:%M:%S")

    # 取前31分钟数据
    else:
        start_dt = now - datetime.timedelta(minutes=31)
        end_dt = now
    start_dt = start_dt.astimezone(tz=LOCAL_TIMEZONE)
    end_dt = end_dt.astimezone(tz=LOCAL_TIMEZONE)
    vod_list_res = gensee_api_post("/webcast/vod/sync",
                                   {"loginName": "admin@zenweiqi.com", "password": "888888", "pageNo": page,
                                    "startTime": start_dt, "endTime": end_dt})
    return vod_list_res
    # try:
    #     if vod_list_res["code"] == "0":
    #         totalPages = vod_list_res["page"]["totalPages"]
    #         page += 1
    #     else:
    #         break
    # except:
    #     break
    # while page <= totalPages:



# -*- coding:utf-8 -*-
from django.dispatch import Signal

# ===user_course====
# 用户课程：新增/结课
# status：0-新增/1-结课
user_course_changed = Signal(providing_args=["user_course", 'status'])

# 作业被评分前发出的信号
assignment_will_be_scored = Signal(providing_args=["user_course_section", "request"])

# 作业评分后发出的信号
assignment_was_scored = Signal(providing_args=["user_course_section", "request"])

# 更新课件直播时长后发送的信号
ucs_update_time = Signal(providing_args=['user_course_section'])
# 课程通过后发送的信号
ucs_passed = Signal(providing_args=['user_course_section'])

# 直播回调后发出的信号
live_callback_finished = Signal(providing_args=["user_live", "coin_multiple"])
# 直播隐藏后发送信号
user_live_delete = Signal(providing_args=["user_live", "op_user"])
# 直播恢复后发送信号
user_live_recover = Signal(providing_args=["user_live", "op_user"])

# 笔记创建的信号
section_note_created = Signal(providing_args=["user_section_note_id"])

# 直播评论后发出的信号
user_live_comment = Signal(providing_args=['user_live', 'comment_user'])

# 认证更新后发送的信号
user_certify_update_status = Signal(providing_args=['user_certify', 'status'])


# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-07-10 07:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0063_auto_20190703_1608'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userlive',
            name='provider_name',
            field=models.CharField(default='cc', max_length=180),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-29 07:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0078_auto_20191023_1625'),
    ]

    operations = [
        migrations.AddField(
            model_name='section',
            name='pass_cooldown',
            field=models.IntegerField(default=0, help_text='\u901a\u8fc7\u65f6\u8ddd\u79bb\u4e0a\u4e00\u8bfe\u4ef6\u7684\u95f4\u9694\u5929\u6570', verbose_name='\u95f4\u9694\u5929\u6570'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-27 07:25
from __future__ import unicode_literals

import bee_django_object_field.custom_fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_course', '0079_section_pass_cooldown'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserCertifyRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.IntegerField(choices=[(0, '\u672a\u63d0\u4ea4'), (1, '\u5df2\u63d0\u4ea4'), (2, '\u901a\u8fc7'), (3, '\u9a73\u56de'), (4, '\u5173\u95ed')], default=0, verbose_name='\u72b6\u6001')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('operated_at', models.DateTimeField(blank=True, null=True, verbose_name='\u64cd\u4f5c\u65f6\u95f4')),
                ('detail', bee_django_object_field.custom_fields.DictField(blank=True, null=True, verbose_name='\u6dfb\u52a0\u65f6\u7684\u8be6\u7ec6\u6570\u636e')),
                ('operator', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='\u64cd\u4f5c\u8005')),
                ('user_course_section', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserCourseSection')),
            ],
            options={
                'ordering': ['-id'],
                'db_table': 'bee_django_course_user_certify_record',
            },
        ),
        migrations.AddField(
            model_name='section',
            name='need_certify',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u9700\u8981\u8ba4\u8bc1'),
        ),
    ]



# -*- coding: utf-8 -*-
__author__ = 'bee'
from django.conf import settings

from qiniu import Auth
from qiniu import BucketManager

# 上传视频到七牛，需要先获取的token
def get_qiniu_token(key):
    if not hasattr(settings, "QINIU_CONFIG"):
        return
    access_key = settings.QINIU_CONFIG.ak
    secret_key = settings.QINIU_CONFIG.sk
    # 构建鉴权对象
    q = Auth(access_key, secret_key)
    # 要上传的空间
    bucket_name = settings.QINIU_CONFIG.bucket_name
    # key 上传后保存的文件名

    # 生成上传 Token，可以指定过期时间等
    # 上传策略示例
    # https://developer.qiniu.com/kodo/manual/1206/put-policy
    policy = {
        # 'callbackUrl':'https://requestb.in/1c7q2d31',
        # 'callbackBody':'filename=$(fname)&filesize=$(fsize)'
        # 'persistentOps':'imageView2/1/w/200/h/200'
    }
    # 3600为token过期时间，秒为单位。3600等于一小时
    token = q.upload_token(bucket_name, key=key.encode('utf-8'), expires=3600, policy=policy)
    return token


def get_video_str(file_name):
    if not hasattr(settings, "QINIU_CONFIG"):
        return ''
    if file_name:
        return "http://" + settings.QINIU_CONFIG.domain + "/" + file_name
    else:
        return ""


# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-03-23 10:42
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0014_auto_20180322_1313'),
    ]

    operations = [
        migrations.AddField(
            model_name='course',
            name='created_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AddField(
            model_name='section',
            name='created_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]



# coding=utf-8
__author__ = 'bee'
import os, datetime, json

from django.core.management.base import BaseCommand, CommandError
from django.utils import timezone

from bee_django_course.utils import gensee_vod_sync


class Command(BaseCommand):
    def handle(self, *args, **options):
        sync_count = gensee_vod_sync()
        print("[" + timezone.localtime().strftime(
            "%Y-%m-%d %H:%M:%S") + "] gensee_vod_sync_count: " + sync_count.__str__())
        return



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-03-22 05:13
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0013_auto_20180322_1240'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserAssignment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content', models.TextField(blank=True, null=True, verbose_name='\u6b63\u6587')),
                ('work_time', models.IntegerField(blank=True, default=0, null=True, verbose_name='\u603b\u5171\u7ec3\u4e60\u65f6\u95f4')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('score', models.IntegerField(blank=True, null=True, verbose_name='\u5f97\u5206')),
                ('updated_at', models.DateTimeField(blank=True, null=True)),
                ('submit_at', models.DateTimeField(blank=True, null=True)),
                ('status', models.IntegerField(default=0)),
                ('comment', models.TextField(blank=True, null=True, verbose_name='\u8bc4\u8bed')),
                ('reviewed_at', models.DateTimeField(blank=True, null=True)),
                ('rejected_at', models.DateTimeField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='UserAssignmentImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.ImageField(upload_to='images/%Y/%m/%d', verbose_name='\u56fe\u7247\u4f5c\u4e1a')),
                ('upload_at', models.DateTimeField(auto_now_add=True, verbose_name='\u4e0a\u4f20\u65f6\u95f4')),
                ('user_assignment', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserAssignment')),
            ],
        ),
        migrations.RemoveField(
            model_name='userassignmenttext',
            name='user_course_section',
        ),
        migrations.RemoveField(
            model_name='usercoursesection',
            name='work_time',
        ),
        migrations.DeleteModel(
            name='UserAssignmentText',
        ),
        migrations.AddField(
            model_name='userassignment',
            name='user_course_section',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserCourseSection'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-15 04:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0027_auto_20180417_1459'),
    ]

    operations = [
        migrations.AddField(
            model_name='course',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to=b'', verbose_name='\u914d\u56fe'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-21 08:03
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0076_section_has_to_finish_course_video'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserCourseSectionVideo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('finish_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('user_course_section', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserCourseSection')),
                ('video', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.Video')),
            ],
        ),
        migrations.AlterField(
            model_name='section',
            name='has_to_finish_course_video',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u9700\u8981\u770b\u5b8c\u8bfe\u4ef6\u6240\u6709\u89c6\u9891(\u53ea\u5bf9\u4e03\u725b\u4e91\u89c6\u9891\u6709\u6548)'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-30 08:25
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0082_userlive_ucs'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='userlive',
            name='ucs',
        ),
        migrations.AddField(
            model_name='usercertifyrecord',
            name='user_live',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserLive'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-26 08:26
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0068_course_template'),
    ]

    operations = [
        migrations.AlterField(
            model_name='course',
            name='template',
            field=models.CharField(blank=True, help_text='\u5728\u9879\u76ee\u4e2dcustom_user\u4e0b\u65b0\u5efa\u6a21\u7248\u6587\u4ef6custom_user_course_section_list_[template].html', max_length=180, null=True, verbose_name='\u6a21\u7248'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'

import pytz, calendar, time,datetime
from calendar import monthrange
from django.utils import timezone

LOCAL_TIMEZONE = pytz.timezone('Asia/Shanghai')


def get_now(tz=LOCAL_TIMEZONE):
    now = timezone.now()
    return now


# 获取今日0点时间，默认返回北京时间
def get_today(tz=LOCAL_TIMEZONE):
    now = timezone.now()
    year = now.strftime("%Y")
    month = now.strftime("%m")
    day = now.strftime("%d")
    today = datetime.datetime(year=int(year), month=int(month), day=int(day), hour=0, minute=0, second=0,
                                 tzinfo=tz)
    return today


# 获取当周周日晚23点23分23秒
def get_current_week_range_datetime():
    today = get_today()
    start_date = today - datetime.timedelta(days=today.weekday())
    end_date = start_date + datetime.timedelta(days=7)
    end_date = end_date - datetime.timedelta(seconds=1)
    # print(start_date,end_date, '1')
    return start_date, end_date


def add_months(dt, months):
    month = dt.month - 1 + months
    year = dt.year + month / 12
    month = month % 12 + 1
    day = min(dt.day, monthrange(year, month)[1])
    return dt.replace(year=year, month=month, day=day)


def add_weeks(weeks):
    today = get_today()
    days = today.weekday()   # 0到6代表周一到到周日
    start_dt = today + datetime.timedelta(days=-days + weeks * 7)
    end_dt = start_dt + datetime.timedelta(7)
    return start_dt, end_dt



# 获取第几周或几月
def get_year_month_week(_datetime):
    year = _datetime.strftime("%Y")
    month = _datetime.strftime("%m")
    week = _datetime.strftime("%W")
    return year, month, week


# 获取开始时间和结束时间
# scope：范围：day/month/week
# offset: 偏移时间，正为延后，负为以前
def get_datetime_with_scope_offset(scope, offset):
    offset=int(offset)
    today = get_today()
    start_time = None
    end_time = None
    if scope == 'day':
        days = offset
        start_time = (today + datetime.timedelta(days=days))
        end_time = (start_time + datetime.timedelta(days=1))
    elif scope == 'month':
        first_day = (today + datetime.timedelta(days=-today.day + 1))
        start_time = add_months(first_day, offset)
        end_time = add_months(first_day, offset + 1)
    elif scope == 'week':
        start_time, end_time = add_weeks(offset)
    return start_time, end_time


# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-09-14 08:26
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0054_section_question_passed_at'),
    ]

    operations = [
        migrations.AddField(
            model_name='usercoursesection',
            name='question_passed',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='question_passed_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-23 08:25
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0077_auto_20191021_1603'),
    ]

    operations = [
        migrations.AlterField(
            model_name='section',
            name='has_to_finish_course_video',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u9700\u8981\u770b\u5b8c\u8bfe\u4ef6\u6240\u6709\u89c6\u9891'),
        ),
        migrations.AlterField(
            model_name='section',
            name='has_videowork',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u9700\u8981\u89c6\u9891\u5f55\u5236'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-21 05:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0067_auto_20190819_1414'),
    ]

    operations = [
        migrations.AddField(
            model_name='course',
            name='template',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u6a21\u7248'),
        ),
    ]
